summaryrefslogtreecommitdiffstats
path: root/tdeui/knuminput.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/knuminput.h')
-rw-r--r--tdeui/knuminput.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/knuminput.h b/tdeui/knuminput.h
index c0a6d1847..5f0127cda 100644
--- a/tdeui/knuminput.h
+++ b/tdeui/knuminput.h
@@ -68,7 +68,7 @@ public:
~KNumInput();
/**
* Sets the text and tqalignment of the main description label.
*
* @param label The text of the label.
* Use TQString::null to remove an existing one.
@@ -77,7 +77,7 @@ public:
* @p AlignTop, @p AlignVCenter, @p AlignBottom.
* default is @p AlignLeft | @p AlignTop.
*
* The vertical tqalignment flags have special meaning with this
* widget:
*
* @li @p AlignTop The label is placed above the edit/slider
@@ -144,7 +144,7 @@ protected:
TQSlider* m_slider;
TQSize m_sizeSlider, m_sizeLabel;
- int m_tqalignment;
+ int m_alignment;
private:
void init();
@@ -314,7 +314,7 @@ public:
/**
* This method returns the minimum size necessary to display the
* control. The minimum size is enough to show all the labels
- * in the current font (font change may tqinvalidate the return value).
+ * in the current font (font change may invalidate the return value).
*
* @return the minimum size necessary to show the control
*/
@@ -68,7 +68,7 @@ public:
~KNumInput();
/**
- * Sets the text and tqalignment of the main description label.
+ * Sets the text and alignment of the main description label.
*
* @param label The text of the label.
@@ -77,7 +77,7 @@ public:
* default is @p AlignLeft | @p AlignTop.
*
- * The vertical tqalignment flags have special meaning with this
+ * The vertical alignment flags have special meaning with this
* widget:
*